==> nuke-number-picker-1.0.6.tgz: package/lib/styles/index.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _variable = require('./variable');

var _variable2 = _interopRequireDefault(_variable);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function styleProvider() {
  var theme = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var Variables = (0, _variable2.default)(theme);
  var core = theme.Core;
  return {
    NumberPicker: {
      'number-picker': {
        flex: 1,
        flexDirection: 'row',
        height: Variables.height
      },
      'input-wrap': _extends({
        margin: '0',
        outline: '0',
        alignSelf: 'center',
        borderRadius: '0',
        textAlign: 'center',
        boxShadow: 'none',
        width: Variables['input-min-width'],
        height: Variables.height,
        color: Variables['input-color'],
        flex: 1,
        fontSize: Variables['input-size-text'],
        backgroundColor: Variables['input-bg-color']
      }, core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'])),
      input: {
        width: Variables['input-min-width'],
        // color:'yellow',
        paddingLeft: 0,
        paddingRight: 0,
        WebkitAppearance: 'none',
        alignItems: 'center',
        textAlign: 'center',
        justifyContent: 'center'
      },
      reduce: _extends({
        justifyContent: 'center',
        alignItems: 'center',
        width: Variables['button-width'],
        height: Variables.height,
        backgroundColor: Variables['button-bg-color']
      }, core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'], 'top'), core.border(0, Variables['border-style'], Variables['border-color'], 'right'), core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'], 'bottom'), core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'], 'left')),
      'reduce-icon': {
        fontSize: Variables['icon-size'],
        color: Variables['icon-color']
      },
      add: _extends({
        justifyContent: 'center',
        alignItems: 'center',
        width: Variables['button-width'],
        height: Variables.height,
        backgroundColor: Variables['button-bg-color']
      }, core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'], 'top'), core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'], 'right'), core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'], 'bottom'), core.border(0, Variables['border-style'], Variables['border-color'], 'left')),
      'add-icon': {
        fontSize: Variables['icon-size'],
        color: Variables['icon-color']
      },
      'error-input-wrap': {
        borderColor: Variables['input-border-color-error']
      },
      'error-input': {
        color: Variables['input-color-error']
      }
    }
  };
}
module.exports = styleProvider;

==> nuke-number-picker-2.0.2.tgz: package/lib/styles/index.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _variable = require('./variable');

var _variable2 = _interopRequireDefault(_variable);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function styleProvider() {
  var theme = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var Variables = (0, _variable2.default)(theme);
  var core = theme.Core;
  return {
    NumberPicker: {
      'number-picker': {
        // flex: 1,
        flexDirection: 'row',
        height: Variables['button-height']
      },
      'input-wrap': _extends({
        margin: 0,
        outline: 0,
        // alignSelf: 'center',
        borderRadius: 0,
        textAlign: 'center',
        boxShadow: 'none',
        // width: Variables['input-min-width'],
        height: Variables['button-height'],
        color: Variables['input-color'],
        flex: 1,
        // minWidth: Variables['input-min-width'],

        paddingLeft: 0,
        paddingRight: 0,
        fontSize: Variables['input-size-text'],
        backgroundColor: Variables['input-bg-color']
      }, core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'])),

      'input-disabled': {
        backgroundColor: Variables['input-bg-color-disabled'],
        color: Variables['input-color-disabled']
      },
      input: {
        // color:'yellow',

        WebkitAppearance: 'none',
        alignItems: 'center',
        textAlign: 'center',
        justifyContent: 'center'
      },
      reduce: _extends({
        justifyContent: 'center',
        alignItems: 'center',
        width: Variables['button-width'],
        height: Variables['button-height'],
        backgroundColor: Variables['button-bg-color'],
        'backgroundColor:active': Variables['button-bg-color-active']
      }, core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'])),
      icon: {
        fontSize: Variables['icon-size'],
        color: Variables['icon-color']
      },
      add: _extends({
        justifyContent: 'center',
        alignItems: 'center',
        width: Variables['button-width'],
        height: Variables['button-height'],
        backgroundColor: Variables['button-bg-color'],
        'backgroundColor:active': Variables['button-bg-color-active']
      }, core.border(Variables['border-width'], Variables['border-style'], Variables['border-color'])),

      'icon-disabled': {
        color: Variables['icon-color-disabled']
      },
      'disabled-button': {
        backgroundColor: Variables['button-bg-color-disabled'],
        'backgroundColor:active': Variables['button-bg-color-disabled']
      },
      'error-input-wrap': {
        borderColor: Variables['input-border-color-error']
      },
      'error-input': {
        color: Variables['input-color-error']
      }
    }
  };
}
module.exports = styleProvider;
